mysql.exceptions.server.Tablename_Not_Allowed_Here

Package mysql :: Package exceptions :: Module server :: Class Tablename_Not_Allowed_Here |
[hide private]
[frames] | no frames]

# Class Tablename_Not_Allowed_Here

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                base.MySQL_Error --+
                                   |
                                  Tablename_Not_Allowed_Here

Table '%s' from one of the SELECTs cannot be used in %s

Instance Methods | [hide private]
Inherited from `base.MySQL_Error`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__getitem__`

Instance Variables | [hide private]
Inherited from `base.MySQL_Error`: `errno`, `error_string`